@@ -1,19 +1,19 @@
 #! /usr/local/bin/perl -w
-# (Updated: $Id: disamb.pl,v 1.10 2005/06/24 13:55:39 sidz1979 Exp $)
+# (Updated: $Id: disamb.pl,v 1.12 2006/12/24 12:18:47 sidz1979 Exp $)
 #
-# disamb.pl version 0.07
+# disamb.pl version 0.09
 #
 # Program that reads in a Senseval-2 formatted lexical sample file, and
 # disambiguates the instances using WordNet::SenseRelate::TargetWord.
 #
 # Copyright (c) 2005
 #
-# Satanjeev Banerjee, Carnegie Mellon University
-# banerjee+@cs.cmu.edu
-#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
+# Satanjeev Banerjee, Carnegie Mellon University
+# banerjee+@cs.cmu.edu
+#
 # Siddharth Patwardhan, University of Utah
 # sidd@cs.utah.edu
 #
@@ -44,14 +44,14 @@ our ($opt_config, $opt_wnpath, $opt_trace, $opt_help, $opt_version);
 &GetOptions("config=s", "wnpath=s", "trace", "help", "version");
 
 # If help is requested
-if (defined $opt_help)
+if(defined $opt_help)
 {
     &printHelp();
     exit;
 }
 
 # If version information is requested
-if (defined $opt_version)
+if(defined $opt_version)
 {
     &printVersion();
     exit;
@@ -61,9 +61,8 @@ if (defined $opt_version)
 my $options = {};
 
 # Load options if any
-if (defined $opt_config)
+if(defined $opt_config)
 {
-
     # Make all the options undefined first
     $options                      = {};
     $options->{preprocess}        = [];
@@ -79,7 +78,7 @@ if (defined $opt_config)
     # Read the configuration file
     my $optStruct = &readConfigFile($opt_config);
     &askHelp("disamb.pl: Configuration file format error.\n")
-      if (!defined $optStruct);
+        if (!defined $optStruct);
 
     # Now get the options from the options structure
     # First, the preprocess modules and options
@@ -107,17 +106,14 @@ if (defined $opt_config)
     # Next, get the context selection module and options
     if (defined $optStruct->{'CONTEXT'})
     {
-
         # There should be only one context selection module specified
-        &askHelp(
-"disamb.pl: Multiple context selection modules specified in configuration file.\n"
-          )
-          if (scalar(@{$optStruct->{'CONTEXT'}}) > 1);
+        &askHelp("disamb.pl: Multiple context selection modules specified in configuration file.\n")
+            if(scalar(@{$optStruct->{'CONTEXT'}}) > 1);
 
         # Get the context selection module name, and options
         # If none are specified, the default will be used
         my $element = shift(@{$optStruct->{'CONTEXT'}});
-        if (defined $element && defined $element->{'name'})
+        if(defined $element && defined $element->{'name'})
         {
             $options->{context} = $element->{'name'};
             delete $element->{'name'};
@@ -128,11 +124,9 @@ if (defined $opt_config)
     # Next, get the algorithm module and options
     if (defined $optStruct->{'ALGORITHM'})
     {
-
         # Only one algorithm module must be specified
-        &askHelp(
-"disamb.pl: Multiple algorithm modules specified in configuration file.\n")
-          if (scalar(@{$optStruct->{'ALGORITHM'}}) > 1);
+        &askHelp("disamb.pl: Multiple algorithm modules specified in configuration file.\n")
+            if(scalar(@{$optStruct->{'ALGORITHM'}}) > 1);
 
         # Get the algorithm module name, and options
         # If none are specified, then the default will be used
@@ -150,7 +144,7 @@ if (defined $opt_config)
 print STDERR "Loading WordNet::SenseRelate::Tools... ";
 my $wntools = WordNet::SenseRelate::Tools->new($opt_wnpath);
 &askHelp("disamb.pl: Unable to load WordNet::SenseRelate::Tools.\n")
-  if (!defined $wntools);
+    if (!defined $wntools);
 print STDERR "done.\n";
 $options->{'wntools'} = $wntools;
 
@@ -161,9 +155,7 @@ my $reader = WordNet::SenseRelate::Reader::Senseval2->new(shift);
 print STDERR "done.\n";
 
 # Create WordNet::SenseRelate::TargetWord object:
-my ($targetWord, $error) =
-  WordNet::SenseRelate::TargetWord->new($options,
-                                        ((defined $opt_trace) ? 1 : 0));
+my ($targetWord, $error) = WordNet::SenseRelate::TargetWord->new($options, ((defined $opt_trace) ? 1 : 0));
 if (!defined $targetWord)
 {
     print STDERR "$error\n";
@@ -192,63 +184,62 @@ foreach my $i (0 .. ($reader->instanceCount() - 1))
 sub readConfigFile
 {
     my $fname = shift;
-
-    open(CONFIG, "$fname")
-      || &askHelp("disamb.pl: Unable to open specified configuration file.\n");
+    
+    open(CONFIG, "$fname") || &askHelp("disamb.pl: Unable to open specified configuration file.\n");
     my $line = <CONFIG>;
     $line =~ s/[\r\f\n]//;
     $line =~ s/^\s+//;
     $line =~ s/\s+$//;
     &askHelp("disamb.pl: File format error (in header) in config file.\n")
-      if ($line !~ /^WordNet::SenseRelate::TargetWord$/);
+        if ($line !~ /^WordNet::SenseRelate::TargetWord$/);
     my $struct  = {};
     my $section = "";
     my $modname = "";
     my $modata  = undef;
-
+    
     while ($line = <CONFIG>)
     {
         $line =~ s/[\r\f\n]//;
         $line =~ s/\#.*//;
         $line =~ s/^\s+//;
         $line =~ s/\s+$//;
-        if ($line =~ /\[SECTION:([^\]]*)\]/)
+        if($line =~ /\[SECTION:([^\]]*)\]/)
         {
             $section = $1;
             $struct->{$section} = []
-              if (   defined $section
-                  && $section ne ""
-                  && !exists($struct->{$section}));
+                if(defined $section
+                   && $section ne ""
+                   && !exists($struct->{$section}));
         }
-        elsif ($line =~ /\[START\s+([^\]]+)\]/)
+        elsif($line =~ /\[START\s+([^\]]+)\]/)
         {
-            return undef if (!defined $section || $section eq "");
+            return undef if(!defined $section || $section eq "");
             $modname = $1;
             $modata  = {};
         }
-        elsif ($line =~ /\[END\]/)
+        elsif($line =~ /\[END\]/)
         {
             return undef
-              if (   !defined $section
-                  || $section eq ""
-                  || !defined $modname
-                  || $modname eq "");
+                if(!defined $section
+                   || $section eq ""
+                   || !defined $modname
+                   || $modname eq "");
             return undef if (!defined $modata);
             $modata->{'name'} = $modname;
             push(@{$struct->{$section}}, $modata);
             $modname = "";
             $modata  = undef;
         }
-        elsif ($line =~ /([^=]+)\s*=\s*([^=]+)/)
+        elsif($line =~ /([^=]+)\s*=\s*([^=]+)/)
         {
             return undef
-              if (   !defined $section
-                  || !defined $modname
-                  || $section eq ""
-                  || $modname eq "");
+                if(!defined $section
+                   || !defined $modname
+                   || $section eq ""
+                   || $modname eq "");
             $modata->{$1} = $2;
         }
-        elsif ($line ne "")
+        elsif($line ne "")
         {
             return undef;
         }
@@ -261,19 +252,13 @@ sub readConfigFile
 # function to output help messages for this program
 sub printHelp
 {
-    print
-      "Performs Word Sense Disambiguation on Senseval-2 lexical sample data.\n";
-    print
-"Usage: disamb.pl [ [--config FILE] [--wnpath WNPATH] [--trace] XMLFILE | --help | --version]\n";
-    print
-      "--config         Specifies a configuration file (FILE) to set up the\n";
+    print "Performs Word Sense Disambiguation on Senseval-2 lexical sample data.\n";
+    print "Usage: disamb.pl [ [--config FILE] [--wnpath WNPATH] [--trace] XMLFILE | --help | --version]\n";
+    print "--config         Specifies a configuration file (FILE) to set up the\n";
     print "                 various configuration options.\n";
-    print
-      "--wnpath         WNPATH specifies the path of the WordNet data files.\n";
-    print
-"                 Ordinarily, this path is determined from the \$WNHOME\n";
-    print
-      "                 environment variable. But this option overides this\n";
+    print "--wnpath         WNPATH specifies the path of the WordNet data files.\n";
+    print "                 Ordinarily, this path is determined from the \$WNHOME\n";
+    print "                 environment variable. But this option overides this\n";
     print "                 behavior.\n";
     print "--trace          Indicates that trace information be printed.\n";
     print "--help           Displays this help screen.\n";
@@ -292,9 +277,8 @@ sub askHelp
 # Subroutine to print the version information
 sub printVersion
 {
-    print "disamb.pl version 0.07\n";
-    print
-"Copyright (c) 2005 Satanjeev Banerjee, Ted Pedersen and Siddharth Patwardhan.\n";
+    print "disamb.pl version 0.09\n";
+    print "Copyright (c) 2005 Ted Pedersen, Satanjeev Banerjee, and Siddharth Patwardhan.\n";
 }
 
 __END__
@@ -339,31 +323,36 @@ B<--version>
 
 =head1 AUTHORS
 
- Siddharth Patwardhan <sidd at cs.utah.edu>
+ Ted Pedersen, University of Minnesota, Duluth
+ tpederse at d.umn.edu
 
- Ted Pedersen <tpederse at d.umn.edu>
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
 
- Satanjeev Banerjee <banerjee+ at cs.cmu.edu>
+ Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+ banerjee+ at cs.cmu.edu
 
-=head1 BUGS
+=head1 KNOWN BUGS
+
+None.
 
 =head1 SEE ALSO
 
 perl(1)
 
-WordNet::SenseRelate::TargetWord(3)
+I<WordNet::SenseRelate::TargetWord>(3pm)
 
-WordNet::Similarity(3)
+I<WordNet::Similarity>(3pm)
 
-http://www.cogsci.princeton.edu/~wn/
+L<ttp://www.cogsci.princeton.edu/~wn>
 
-http://senserelate.sourceforge.net
+L<http://senserelate.sourceforge.net>
 
-http://groups.yahoo.com/group/senserelate/
+L<http://groups.yahoo.com/group/senserelate>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Siddharth Patwardhan, Ted Pedersen, Satanjeev
+Copyright (c) 2005 Ted Pedersen, Siddharth Patwardhan, Satanjeev
 Banerjee
 
 This program is free software; you can redistribute it and/or modify it
