@@ -1,7 +1,7 @@
 #! /usr/local/bin/perl -w
-# (Updated: $Id: wps2sk.pl,v 1.6 2005/06/24 13:55:39 sidz1979 Exp $)
+# (Updated: $Id: wps2sk.pl,v 1.8 2006/12/24 12:18:47 sidz1979 Exp $)
 #
-# wps2sk.pl version 0.2
+# wps2sk.pl version 0.09
 #
 # Program to convert SENSEVAL answer files with answers in the
 # word#pos#sense format to mnemonics using the word#pos#sense -
@@ -9,12 +9,12 @@
 #
 # Copyright (c) 2005
 #
-# Satanjeev Banerjee, Carnegie Mellon University
-# banerjee+@cs.cmu.edu
-#
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse@d.umn.edu
 #
+# Satanjeev Banerjee, Carnegie Mellon University
+# banerjee+@cs.cmu.edu
+#
 # Siddharth Patwardhan, University of Utah
 # sidd@cs.utah.edu
 #
@@ -206,9 +206,9 @@ sub askHelp
 # Subroutine to print the version information
 sub printVersion
 {
-    print "wps2sk.pl version 0.2\n";
+    print "wps2sk.pl version 0.09\n";
     print
-"Copyright (c) 2005 Satanjeev Banerjee, Ted Pedersen and Siddharth Patwardhan.\n";
+"Copyright (c) 2005 Ted Pedersen, Satanjeev Banerjee, and Siddharth Patwardhan.\n";
 }
 
 
@@ -245,31 +245,36 @@ B<--version>
 
 =head1 AUTHORS
 
- Siddharth Patwardhan <sidd at cs.utah.edu>
+ Ted Pedersen, University of Minnesota, Duluth
+ tpederse at d.umn.edu
 
- Ted Pedersen <tpederse at d.umn.edu>
+ Siddharth Patwardhan, University of Utah, Salt Lake City
+ sidd at cs.utah.edu
 
- Satanjeev Banerjee <banerjee+ at cs.cmu.edu>
+ Satanjeev Banerjee, Carnegie Mellon University, Pittsburgh
+ banerjee+ at cs.cmu.edu
 
-=head1 BUGS
+=head1 KNOWN BUGS
+
+None.
 
 =head1 SEE ALSO
 
-perl(1)
+I<perl>(1pm)
 
-WordNet::SenseRelate::TargetWord(3)
+I<WordNet::SenseRelate::TargetWord>(3pm)
 
-WordNet::Similarity(3)
+I<WordNet::Similarity>(3pm)
 
-http://www.cogsci.princeton.edu/~wn/
+L<http://www.cogsci.princeton.edu/~wn>
 
-http://senserelate.sourceforge.net
+L<http://senserelate.sourceforge.net>
 
-http://groups.yahoo.com/group/senserelate/
+L<http://groups.yahoo.com/group/senserelate>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 Siddharth Patwardhan, Ted Pedersen, Satanjeev
+Copyright (c) 2005 Ted Pedersen, Siddharth Patwardhan, Satanjeev
 Banerjee
 
 This program is free software; you can redistribute it and/or modify it
